@@ -22,7 +22,8 @@ implementations.
 * [Transformer building blocks](transformers/models.html)
 * [Transformer XL](transformers/xl/index.html)
     * [Relative multi-headed attention](transformers/xl/relative_mha.html)
-* [Rotary Positional Embeddings](transformers/rope/index.html)
+* [Rotary Positional Embeddings (RoPE)](transformers/rope/index.html)
+* [Attention with Linear Biases (ALiBi)](transformers/alibi/index.html)
 * [RETRO](transformers/retro/index.html)
 * [Compressive Transformer](transformers/compressive/index.html)
 * [GPT Architecture](transformers/gpt/index.html)
@@ -52,6 +53,8 @@ implementations.
 
 #### ✨ [Capsule Networks](capsule_networks/index.html)
 
+#### ✨ [U-Net](unet/index.html)
+
 #### ✨ [Generative Adversarial Networks](gan/index.html)
 * [Original GAN](gan/original/index.html)
 * [GAN with deep convolutional network](gan/dcgan/index.html)
@@ -116,6 +119,17 @@ Solving games with incomplete information such as poker with CFR.
 
 * [Fuzzy Tiling Activations](activations/fta/index.html)
 
+#### ✨ [Sampling Techniques](sampling/index.html)
+* [Greedy Sampling](sampling/greedy.html)
+* [Temperature Sampling](sampling/temperature.html)
+* [Top-k Sampling](sampling/top_k.html)
+* [Nucleus Sampling](sampling/nucleus.html)
+
+#### ✨ [Eleuther GPT-NeoX](neox/index.html)
+
+#### ✨ [Scalable Training/Inference](scaling/index.html)
+* [Zero3 memory optimizations](scaling/zero3/index.html)
+
 ## Highlighted Research Paper PDFs
 
 * [Autoregressive Search Engines: Generating Substrings as Document Identifiers](https://github.com/labmlai/annotated_deep_learning_paper_implementations/blob/master/papers/2204.10628.pdf)
